MII Implementierungsleitfaden Kerndatensatz-Modul Molekulargenetischer Befundbericht
2027.0.0-ballot.1 -
Germany
MII IG Kerndatensatz-Modul Molekulargenetischer Befundbericht - Downloaded Version 2027.0.0-ballot.1 See the Directory of published versions
Language: de
Bundle mii-exa-befund-bundle-1-braf of type transaction
Entry 1 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-befundbericht-1
Resource DiagnosticReport:
Language: de
Profiles: MII PR MolGen Molekulargenetischer Befundbericht version: 2027.0.0-ballot.1, Genomic Report version: 3.0.0
Genetic analysis report (Genetics)
Subject Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, )) Performer Practitioner Dr. Daniel Schmidt(official) Report Details
Code Value Flags Relevant Time Diagnostic Implication Final 2022-04-07 Therapeutic Implication Final 2022-04-07 Genetic variant assessment Present Final 2022-04-07 Genotype display name BRAF rs113488022 T>A Final 2022-04-07 Mutations/Megabase [# Ratio] in Tumor 12 Mutations/Megabase (Details: UCUM code1/1000000{Base} = '1/1000000{Base}') Final Microsatellite instability [Interpretation] in Cancer specimen Qualitative Stable Final BRAF p.V600E Mutation liegt vor. Bitte Therapieoption mit einem BRAF-Inhibitor prüfen.
Request:
PUT DiagnosticReport/mii-exa-molgen-befundbericht-1
Entry 2 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-medikationsempfehlung-1
Resource Task:
Language: de
Profiles: MII PR MolGen Medikationsempfehlung version: 2027.0.0-ballot.1, Medication Recommendation version: 3.0.0
basedOn: ServiceRequest Molecular genetic test (procedure)
status: Requested
intent: Proposal
code: Alternative Medikation in Erwägung ziehen
for: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
Request:
PUT Task/mii-exa-molgen-medikationsempfehlung-1
Entry 3 - fullUrl = https://www.medizininformatik-initiative.de/fhir/example-mii-molgen-folgemassnahme-1
Resource Task:
Language: de
Profiles: MII PR MolGen Empfohlene Folgemaßnahme version: 2027.0.0-ballot.1, Followup Recommendation version: 3.0.0
basedOn: ServiceRequest Molecular genetic test (procedure)
status: Requested
intent: Proposal
code: Genetic counseling recommended
description: Genetische Beratung empfohlen mit Dr. Rosalind Franklin
for: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
Request:
PUT Task/mii-exa-molgen-folgemassnahme-1
Entry 4 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-family-member-history-1
Resource FamilyMemberHistory:
Language: de
Profile: MII PR MolGen Familienanamnese version: 2027.0.0-ballot.1
status: Completed
patient: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
date: 2022-04-07
relationship: Mother (person)
sex: Female (finding)
deceased: true
Conditions
Code ContributedToDeath Malignant melanoma with B-Raf proto-oncogene, serine/threonine kinase V600E mutation (disorder) true
Request:
PUT FamilyMemberHistory/mii-exa-molgen-family-member-history-1
Entry 5 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-anforderung-1
Resource ServiceRequest:
Language: de
Profile: MII PR MolGen Anforderung genetischer Test version: 2027.0.0-ballot.1
status: Active
intent: Order
category: Laboratory procedure (procedure)
code: No display for ServiceRequest.code (concept: Molecular genetic test (procedure))
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
authoredOn: 2022-04-07
requester: Practitioner Dr. Linda Rubens(official)
supportingInfo: No display for ServiceRequest.supportingInfo (reference: ->FamilyMemberHistory: status = completed; date = 2022-04-07; relationship = Mother (person); sex = Female (finding); deceased[x] = true; reasonCode = Adenocarcinoma of anorectum (disorder))
Request:
PUT ServiceRequest/mii-exa-molgen-anforderung-1
Entry 6 - fullUrl = https://www.medizininformatik-initiative.de/fhir/example-mii-molgen-patient
Resource Patient:
Language: de
Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
Deceased: false Other Ids:
- Gesetzliche Krankenversicherung/Z234567890 (use: official, )
- Private Krankenversicherung/123456 (use: secondary, )
Alt. Name: Haffer (Name changed for Marriage) Contact Detail Anna-Louisa-Karsch Str. 2 Berlin DE-BE 10178 DE
Request:
PUT Patient/mii-exa-molgen-patient
Entry 7 - fullUrl = https://www.medizininformatik-initiative.de/fhir/example-mii-molgen-practitioner-lab
Resource Practitioner:
Language: de
active: true
name: Dr. Daniel Schmidt(Official)
Request:
PUT Practitioner/mii-exa-molgen-practitioner-lab
Entry 8 - fullUrl = https://www.medizininformatik-initiative.de/fhir/example-mii-molgen-specimen-1
Resource Specimen:
Language: de
identifier:
https://biobank.uk-musterstadt.de/fhir/sid/proben/5432status: Available
type: Tissue specimen from colon (specimen)
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
Collections
Collected[x] BodySite 2022-03-24 12:44:00+0100 No display for Specimen.collection.bodySite (concept: Colon structure (body structure))
Request:
PUT Specimen/mii-exa-molgen-specimen-1
Entry 9 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-diagnostische-implikation-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Diagnostische Implikation version: 2027.0.0-ballot.1, Diagnostic Implication version: 3.0.0
status: Final
category: Laboratory, Genetics
code: Diagnostic Implication
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
effective: 2022-04-07
performer: Practitioner Dr. Daniel Schmidt(official)
derivedFrom: Observation Genetic variant assessment
Components
Code Value[x] Conclusion Text Nachweis einer aktivierenden Mutation BRAF V600E
Request:
PUT Observation/mii-exa-molgen-diagnostische-implikation-1
Entry 10 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-therapeutische-implikation-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Therapeutische Implikation version: 2027.0.0-ballot.1, Therapeutic Implication version: 3.0.0
status: Final
category: Laboratory, Genetics
code: Therapeutic Implication
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
effective: 2022-04-07
performer: Practitioner Dr. Daniel Schmidt(official)
derivedFrom: Observation Genetic variant assessment
component
code: Conclusion Text
value: Nachweis einer aktivierenden Mutation BRAF V600E. Triple-Therapie mit einem EGFR-Antikörper sowie einem BRAF- und einem MEK- Inhibitor prüfen.
component
code: Medication assessed [ID]
value: BRAF Inhibitor
component
code: Medication assessed [ID]
value: EGFR (Epidermal Growth Factor Receptor) inhibitors
component
code: Medication assessed [ID]
value: Mitogen-activated protein kinase (MEK) inhibitors
Request:
PUT Observation/mii-exa-molgen-therapeutische-implikation-1
Entry 11 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-variante-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Variante version: 2027.0.0-ballot.1, Variant version: 3.0.0
basedOn: ServiceRequest Molecular genetic test (procedure)
status: Final
category: Laboratory, Genetics
code: Genetic variant assessment
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
effective: 2022-04-07
value: Present
method: Sequencing
device: Device: status = active; manufacturer = Illumina
component
code: Gene studied [ID]
value: BRAF
component
code: Genomic reference sequence [ID]
value: NM_004333.4
component
code: DNA region name [Identifier]
value: Exon #15
component
code: DNA region name [Identifier]
value: Codon #582 - #612
component
code: DNA change (c.HGVS)
value: NM_004333.4:c.1799T>A
component
code: Amino acid change (pHGVS)
value: p.(Val600Glu)
component
code: Sample variant allelic frequency [NFr]
value: 30.25 % (Details: UCUM code% = '%')
component
code: Cytogenetic (chromosome) location
value: 7q34
component
code: DNA change type
value: point_mutation
component
code: Discrete genetic variant
value: rs113488022
Request:
PUT Observation/mii-exa-molgen-variante-1
Entry 12 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-genotyp-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Genotyp version: 2027.0.0-ballot.1, Genotype version: 3.0.0
status: Final
category: Laboratory, Genetics
code: Genotype display name
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
effective: 2022-04-07
value: BRAF rs113488022 T>A
method: Sequencing
device: Device: status = active; manufacturer = Illumina
derivedFrom: Observation Genetic variant assessment
component
code: Gene studied [ID]
value: BRAF
component
code: Cytogenetic (chromosome) location
value: 7q34
Request:
PUT Observation/mii-exa-molgen-genotyp-1
Entry 13 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-mutationslast-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Mutationslast version: 2027.0.0-ballot.1, Molecular Biomarker version: 3.0.0
status: Final
category: Laboratory, A characterization of a given biomarker observation.
code: Mutations/Megabase [# Ratio] in Tumor
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
performer: Practitioner Dr. Daniel Schmidt(official)
value: 12 Mutations/Megabase (Details: UCUM code1/1000000{Base} = '1/1000000{Base}')
Request:
PUT Observation/mii-exa-molgen-mutationslast-1
Entry 14 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-device-sequencer
Resource Device:
Language: de
status: Active
manufacturer: Illumina
Request:
PUT Device/mii-exa-molgen-device-sequencer
Entry 15 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-practitioner-physician
Resource Practitioner:
Language: de
active: true
name: Dr. Linda Rubens(Official)
Request:
PUT Practitioner/mii-exa-molgen-practitioner-physician
Entry 16 - fullUrl = https://www.medizininformatik-initiative.de/fhir/mii-exa-molgen-mikrosatelliteninstabilitaet-1
Resource Observation:
Language: de
Profiles: MII PR MolGen Mikrosatelliteninstabilität version: 2027.0.0-ballot.1, Molecular Biomarker version: 3.0.0
status: Final
category: Laboratory, A characterization of a given biomarker observation.
code: Microsatellite instability [Interpretation] in Cancer specimen Qualitative
subject: Maja Julia Van-der-Dussen (official) Female, DoB: 1968-09-19 ( Medical record number (use: usual, ))
value: Stable
Request:
PUT Observation/mii-exa-molgen-mikrosatelliteninstabilitaet-1